@@ -1,6 +1,6 @@
 ;;; postgres-gxrepl.scm --- like psql(1) but still evolving
 
-;; Copyright (C) 2005, 2006, 2008, 2009 Thien-Thi Nguyen
+;; Copyright (C) 2005, 2006, 2008, 2009, 2011 Thien-Thi Nguyen
 ;;
 ;; This file is part of Guile-PG.
 ;;
@@ -109,7 +109,7 @@ is normal."
                (with-output-to-string
                  (lambda ()
                    (pretty-print (let ((all (procedure-source proc)))
-                                   (list* (car all)
+                                   (cons* (car all)
                                           (cadr all)
                                           ;; skip docstring
                                           (cdddr all)))))))))
@@ -182,11 +182,11 @@ Exiting from the recursive repl returns to this one."
 ;; The repl accepts two kinds of commands:
 ;;
 ;; @itemize
-;; @item SQL statements such as "CREATE TABLE" or "SELECT" are
-;; executed using @code{pg-exec}.
+;; @item SQL statements such as @code{CREATE TABLE} or
+;; @code{SELECT} are executed using @code{pg-exec}.
 ;;
 ;; @item @dfn{Comma commands} are short commands beginning with
-;; a comma (the most important being ",help") that do various
+;; a comma (the most important being @samp{,help}) that do various
 ;; meta-repl or prepackaged operations.
 ;; @end itemize
 ;;
