@@ -1,6 +1,6 @@
 ;;; postgres-qcons.scm --- construct SELECT queries
 
-;; Copyright (C) 2005, 2006, 2007, 2008, 2009 Thien-Thi Nguyen
+;; Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011 Thien-Thi Nguyen
 ;;
 ;; This file is part of Guile-PG.
 ;;
@@ -47,6 +47,7 @@
             sql-pre?
             sql-unpre
             sql-quote
+            idquote
             make-comma-separated-tree
             make-WHERE-tree
             make-GROUP-BY-tree
@@ -64,7 +65,7 @@
 ;;; mirroring bootstrap
 
 ;; Naming convention: Hash tables begin with "==".  They are
-;; initialized on module load and updated by `qcons-declare!'.
+;; initialized on module load and updated by ‘qcons-declare!’.
 
 (define-macro (define-hash name size pair? init)
   `(begin
@@ -85,11 +86,12 @@
 
 (define *infix-operations*              ; entry: NAME
   (append! '(|| ||/ |/ / !! % ^ * - +
-                     @ & | #{#}# << >>
-                       #{##}# && &< &>
-                       <-> <^ >^ #{?#}#
+                     @ & | << >>
+                       && &< &>
+                       <-> <^ >^
                        ?- ?-| @-@ ?| ?||
                        @@ ~= <<= >>=)
+           (map string->symbol '("#" "##" "?#"))
            *conditional-operations*))
 
 (define-hash ==infix-operations 67 #f *infix-operations*)
@@ -236,18 +238,66 @@
 (define (fs s . args)
   (apply simple-format #f s args))
 
+;; Return the @dfn{quoted identifier} form of @var{id}, a string
+;; or symbol.  The returned string is marked by @code{sql-pre}.
+;; For example:
+;;
+;; @lisp
+;; (define (try x)
+;;   (display (idquote x))
+;;   (newline))
+;;
+;; (try 'abcd)       @print{} "abcd"
+;; (try 'ab.cd)      @print{} "ab"."cd"
+;; (try 'abcd[xyz])  @print{} "abcd"[xyz]
+;; (try 'ab.cd[xyz]) @print{} "ab"."cd"[xyz]
+;; @end lisp
+;;
+;; Note that PostgreSQL case-folding for non-quoted identifiers
+;; is nonstandard.  The PostgreSQL documentation says:
+;;
+;; @quotation
+;; If you want to write portable applications you are advised
+;; to always quote a particular name or never quote it.
+;; @cite{Section 4.1.1, Identifiers and Keywords}
+;; @end quotation
+;;
+;; The qcons module (@pxref{Query Construction}) uses @code{idquote}
+;; internally extensively.
+;;
+(define (idquote id)
+  (sql-pre
+   (let* ((s (if (symbol? id)
+                 (symbol->string id)
+                 id))
+          (ra (string-index s #\[))
+          (dot (string-index s #\.)))
+     (cond
+      ;; Fast path; no complications.
+      ((not (or ra dot))
+       (object->string s))
+      ;; Just dot (ab.cd => "ab"."cd").
+      ((and dot (not ra))
+       (fs "~S.~S"
+           (substring s 0 dot)
+           (substring s (1+ dot))))
+      ;; Just array (abcd[xyz] => "abcd"[xyz]).
+      ((and ra (not dot))
+       (fs "~S~A"
+           (substring s 0 ra)
+           (substring s ra)))
+      ;; Both dot and array (ab.cd[xyz] => "ab"."cd"[xyz]).
+      (#t
+       (fs "~S.~S~A"
+           (substring s 0 dot)
+           (substring s (1+ dot) ra)
+           (substring s (ra))))))))
+
 (define (maybe-dq sym)
+  ;; Hmmm, why not use ‘idquote’ also for this?
   (if (eq? '* sym)
       sym
-      (let ((s (symbol->string sym)))
-        ;; double quote unless table name or array member syntax is
-        ;; included; this is to protect against a column name that
-        ;; happens to be a keyword (e.g., `desc')
-        (if (or (string-index s #\.)
-                (string-index s #\[)
-                (string-index s #\]))
-            sym
-            (sql-pre (fs "~S" s))))))
+      (idquote sym)))
 
 (define (list-sep-proc sep)
   (lambda (proc ls . more-ls)
@@ -273,12 +323,12 @@
   `(#:%LPAREN ,@x #:%RPAREN))
 
 ;; Return a tree made by mapping @var{proc} over list @var{ls},
-;; w/ elements separated by commas.  Optional third arg @var{parens?}
+;; with elements separated by commas.  Optional third arg @var{parens?}
 ;; non-@code{#f} includes surrounding parentheses.  The rest of the args
 ;; are more lists, whose @sc{car}s are passed as additional args
 ;; to @var{proc}.
 ;;
-;;-sig: (proc ls [parens? [more-ls...]])
+;;-args: (- 0 2 parens? more-ls)
 ;;
 (define (make-comma-separated-tree proc ls . opts)
   ((if (and (not (null? opts)) (car opts))
@@ -344,7 +394,7 @@
                                    rest))))
              ((regexp-exec any/all-rx (symbol->string op))
               => (lambda (m)
-                   ;; FIXME: Debug :-/ and use `match:suffix'.
+                   ;; FIXME: Debug :-/ and use ‘match:suffix’.
                    (let ((s (vector-ref m 0)))
                      (paren (expr (car rest))
                             (sql-pre (substring s 5))
@@ -381,8 +431,8 @@
 ;; Return a @dfn{order-by clause} tree for @var{orderings} (a list).
 ;; Each element of @var{orderings} has the form: @code{(ORDFUNC EXPR)}.
 ;; If @var{ordfunc} is the symbol @code{<} or the keyword @code{#:ASC},
-;; it is taken as "ASC".  Likewise, @code{>} or @code{#:DESC} is taken
-;; as "DESC".
+;; it is taken as @code{ASC}.  Likewise, @code{>} or @code{#:DESC} is taken
+;; as @code{DESC}.
 ;;
 (define (make-ORDER-BY-tree orderings)
   (list #:ORDER-BY
@@ -497,7 +547,7 @@
 ;; @var{froms} and @var{cols} (both lists).  In addition to the
 ;; constituent processing done by @code{make-SELECT/COLS-tree}
 ;; and @code{make-FROM-tree} on @var{cols} and @var{froms},
-;; respectively, prefix a "SELECT" token.  If @var{froms} is
+;; respectively, prefix a @code{SELECT} token.  If @var{froms} is
 ;; @code{#f}, it is omitted.
 ;;
 (define (make-SELECT/FROM/COLS-tree froms cols)
