@@ -1,7 +1,7 @@
 ;;; basic.scm
 
-;; Copyright (C) 2002, 2003, 2004, 2005,
-;;   2006, 2007, 2008, 2009, 2010 Thien-Thi Nguyen
+;; Copyright (C) 2002, 2003, 2004, 2005, 2006,
+;;   2007, 2008, 2009, 2010, 2011 Thien-Thi Nguyen
 ;; Portions Copyright (C) 1999, 2000 Ian Grant
 ;;
 ;; This file is part of Guile-PG.
@@ -180,6 +180,16 @@
              (not (= 0 v))
              (< 1 v))))))
 
+(define test:tracing-traced-connection
+  (add-test #f
+    (lambda ()
+      (define (one!)
+        (pg-trace *C* (current-error-port)))
+      (one!)
+      (let ((rv (false-if-exception (one!))))
+        (pg-untrace *C*)
+        rv))))
+
 (define test:untracing-untraced-connection
   (add-test (if #f #f)
     (lambda ()
@@ -190,7 +200,7 @@
     (lambda ()
       ;; Starting with PostgreSQL 8.0, "UTF8" is more correct than "UNICODE".
       ;; This is not mentioned until the 8.1 release notes, however.  :-/
-      ;; Perhaps this should be moved into `pg-client-encoding' proper.
+      ;; Perhaps this should be moved into ‘pg-client-encoding’ proper.
       (define (normalized-cenc)
         (let ((s (pg-client-encoding *C*)))
           (case (string->symbol s)
@@ -336,13 +346,13 @@
 (define test:set-client-data
   (add-test 'defunct
     (lambda ()
-      ;; `pg-set-client-data!' was removed in Guile-PG 0.39.
+      ;; ‘pg-set-client-data!’ was removed in Guile-PG 0.39.
       'defunct)))
 
 (define test:get-client-data
   (add-test 'defunct
     (lambda ()
-      ;; `pg-get-client-data' was removed in Guile-PG 0.39.
+      ;; ‘pg-get-client-data’ was removed in Guile-PG 0.39.
       'defunct)))
 
 (define test:make-table
@@ -438,7 +448,7 @@
 (define test:get-connection
   (add-test 'defunct
     (lambda ()
-      ;; Although `pg-get-connection' was removed for the "more modesty"
+      ;; Although ‘pg-get-connection’ was removed for the "more modesty"
       ;; release (pre-announced in Guile-PG 0.37), we leave this test here.
       'defunct)))
 
@@ -706,7 +716,7 @@
        ;; mask bugs.
        (command-ok? (cexec "NOTIFY \"sooper-sikret message\""))
        ;; Post-checks: Although one notification is all we want, we need to
-       ;; use short-circuit `or' for the "first" in this post-checks series.
+       ;; use short-circuit ‘or’ for the "first" in this post-checks series.
        ;; Subsequent checks are invalid.
        (let ((ans (or (pg-notifies *C*) (pg-notifies *C* #t))))
          (and (pair? ans)
@@ -737,8 +747,8 @@
        ((ok? 'PGRES_COPY_IN) (cexec "COPY async FROM STDIN"))
        (begin
          (and (memq 'PQPROTOCOLVERSION (pg-guile-pg-loaded))
-              ;; Test fails for PostgreSQL 7.4.12 at `pg-endcopy' if omitted.
-              ;; This needs to be done prior to `pg-putline', as well.
+              ;; Test fails for PostgreSQL 7.4.12 at ‘pg-endcopy’ if omitted.
+              ;; This needs to be done prior to ‘pg-putline’, as well.
               (pg-set-nonblocking! *C* #f))
          (do ((i 4224 (1- i)))
              ((= i 0))
@@ -753,7 +763,7 @@
            ((1) (begin (sleep 1) (loop (pg-flush *C*))))
            (else #f)))
        ;; Perhaps usage protocol does not absolutely require this check, but
-       ;; removing it causes the subsequent `pg-send-query' to return #f, with
+       ;; removing it causes the subsequent ‘pg-send-query’ to return #f, with
        ;; error message "another command is already in progress".
        (not (pg-is-busy? *C*))
        ;; Register a query.
@@ -798,11 +808,12 @@
                   (newline))))
          ;; Sync up with the cancellation.
          (and (not (tuples-ok? (pg-get-result *C*)))
-              (return-it #t (format #t "INFO: (~A)\n"
-                                    (let ((reason (pg-error-message *C*)))
-                                      (if (string-null? reason)
-                                          "cancellation"
-                                          reason))))))))))
+              (begin (format #t "INFO: (~A)\n"
+                             (let ((reason (pg-error-message *C*)))
+                               (if (string-null? reason)
+                                   "cancellation"
+                                   reason)))
+                     #t)))))))
 
 (define test:close
   (add-test #t
@@ -813,12 +824,13 @@
 
 (define (main)
   (set! verbose #t)
-  (test-init "basic" 58)
+  (test-init "basic" 59)
   (test! test:pg-guile-pg-loaded
          test:pg-conndefaults
          test:protocol-version/bad-connection
          test:make-connection
          test:protocol-version
+         test:tracing-traced-connection
          test:untracing-untraced-connection
          test:various-connection-info
          test:mblen
