@@ -1,4 +1,4 @@
-;; Copyright (C) 2004, 2006, 2008 Thien-Thi Nguyen
+;; Copyright (C) 2004, 2006, 2008, 2011 Thien-Thi Nguyen
 ;; Copyright (C) 1996, 1997, 1998 Per Bothner.
 ;;
 ;; Usage:
@@ -217,11 +217,10 @@
         (else (display "ERROR: fresh! failed. Giving up.\n")
               (exit #f))))
 
-(define (manually-load . parts)
-  (let ((dir (getenv "tscm")))
-    (for-each (lambda (part)
-                (load (in-vicinity dir (string-append
-                                        "postgres-" part ".scm"))))
-              parts)))
+
+;;; load-time actions
+
+(cond ((getenv "DEBUG")
+       (set! %load-verbosely #t)))
 
 ;;; testing.scm ends here
